@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-# Copyright (C) 2008-2018 Sergey Poznyakoff
+# Copyright (C) 2008-2024 Sergey Poznyakoff
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -659,7 +659,7 @@ class WikiMarkupParser(object):
                         self.dprint(80, "LEAVE parse_ref=None")
                         return None
             elif tok.type == 'OTAG':
-                list.append(self.parse_tag(tok))
+                seq.append(self.parse_tag(tok))
             else:
                 seq.append(tok)
 
@@ -1024,10 +1024,7 @@ class WikiMarkup(WikiMarkupParser):
             elif kw == 'filename':
                 self.file = open(keywords[kw])
             elif kw == 'text':
-                if sys.version_info[0] > 2:
-                    self.text = keywords[kw].decode('utf-8').split("\n")
-                else:
-                    self.text = keywords[kw].split("\n")
+                self.text = keywords[kw].split("\n")
             elif kw == 'lang':
                 self.lang = keywords[kw]
             elif kw == 'html_base':
